[PATCH] D142232: Increase inline threshold multiplier to 11 in nvptx backend.

Jack Kirk via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Fri Feb 3 10:27:57 PST 2023


JackAKirk updated this revision to Diff 494686.
JackAKirk added a comment.

Updated multiplier threshold comment.


Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D142232/new/

https://reviews.llvm.org/D142232

Files:
  llvm/lib/Target/NVPTX/NVPTXTargetTransformInfo.h


Index: llvm/lib/Target/NVPTX/NVPTXTargetTransformInfo.h
===================================================================
--- llvm/lib/Target/NVPTX/NVPTXTargetTransformInfo.h
+++ llvm/lib/Target/NVPTX/NVPTXTargetTransformInfo.h
@@ -90,9 +90,9 @@
     return true;
   }
 
   // Increase the inlining cost threshold by a factor of 5, reflecting that
   // calls are particularly expensive in NVPTX.
-  unsigned getInliningThresholdMultiplier() { return 5; }
+  unsigned getInliningThresholdMultiplier() { return 11; }
 
   InstructionCost getArithmeticInstrCost(
       unsigned Opcode, Type *Ty, TTI::TargetCostKind CostKind,


-------------- next part --------------
@@ -90,9 +90,9 @@
   }
 
-  // Increase the inlining cost threshold by a factor of 5, reflecting that
+  // Increase the inlining cost threshold by a factor of 11, reflecting that
   // calls are particularly expensive in NVPTX.
A non-text attachment was scrubbed...
Name: D142232.494686.patch
Type: text/x-patch
Size: 705 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20230203/1c2d0e6d/attachment-0001.bin>


More information about the llvm-commits mailing list